# Generated by roxygen2: do not edit by hand

S3method(print,Portfolio)
export(Household)
export(HouseholdMember)
export(calc_effective_tax_rate)
export(calc_gompertz_joint_parameters)
export(calc_gompertz_mode)
export(calc_gompertz_parameters)
export(calc_gompertz_survival_probability)
export(calc_life_expectancy)
export(calc_optimal_asset_allocation)
export(calc_optimal_risky_asset_allocation)
export(calc_portfolio_parameters)
export(calc_purchasing_power)
export(calc_retirement_ruin)
export(calc_risk_adjusted_return)
export(create_portfolio_template)
export(format_currency)
export(format_percent)
export(get_cache_info)
export(get_current_date)
export(get_default_gompertz_parameters)
export(plot_expected_allocation)
export(plot_expected_capital)
export(plot_future_income)
export(plot_future_saving_rates)
export(plot_future_spending)
export(plot_gompertz_calibration)
export(plot_joint_survival)
export(plot_life_expectancy)
export(plot_optimal_portfolio)
export(plot_purchasing_power)
export(plot_retirement_ruin)
export(plot_risk_adjusted_returns)
export(plot_scenarios)
export(plot_survival)
export(read_hmd_life_tables)
export(render_scenario_snapshot)
export(reset_cache)
export(run_app)
export(set_cache)
export(simulate_scenario)
export(simulate_scenarios)
